# Generated by roxygen2: do not edit by hand

export(anycensus)
export(detect_adm2_type)
export(load_districts)
export(set_kosis_key)
import(sf)
importFrom(dplyr,filter)
importFrom(dplyr,mutate)
importFrom(kosis,kosis.setKey)
importFrom(rlang,is_installed)
importFrom(sf,st_read)
importFrom(tidyr,pivot_wider)
importFrom(utils,data)
