% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/load_districts.R
\name{load_districts}
\alias{load_districts}
\title{Load district boundaries for a specific year}
\usage{
load_districts(year = 2020)
}
\arguments{
\item{year}{The year for which to load district boundaries (2010, 2015, or 2020)}
}
\value{
An \code{sf} object containing district boundaries for the specified year
}
\description{
Load district boundaries for a specific year
}
\note{
This function requires the \code{tidycensuskr.sf} package to be installed.
No explicit dependency is defind; but users should install the package following
the instructions at vignette('v01_intro') or more succinctly:
\code{install.packages('tidycensuskr.sf', repos = 'https://sigmafelix.r-universe.dev')}
}
