% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{adm2_sf_2020}
\alias{adm2_sf_2020}
\title{South Korea Census Boundary in 2020}
\format{
A sf object with 250 rows and 3 variables:
}
\source{
\itemize{
\item Statistical Geographic Information Service (SGIS)
}
}
\usage{
adm2_sf_2020
}
\description{
District level boundary data in South Korea in 2020. \code{adm2_code} column
can be used to join with an \code{\link[=anycensus]{anycensus()}} output.
}
\details{
\itemize{
\item year Year of the census data, e.g., 2010, 2015, or 2020
\item adm2_code  Code of the district/municipal-level (Sigungu) administrative unit
\item geometry Geometry list-column
}
}
\keyword{datasets}
