% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{kr_grid_adm2_sgis_2020}
\alias{kr_grid_adm2_sgis_2020}
\title{geofacet Grid for South Korea Administrative Districts (SGIS Standard, 2020)}
\format{
A data.frame with 250 rows and 6 variables
}
\source{
\itemize{
\item Statistical Geographic Information Service (SGIS)
\item GitHub username chichead in \href{https://github.com/hafen/geofacet/issues/358}{GitHub geofacet issue page}
}
}
\usage{
kr_grid_adm2_sgis_2020
}
\description{
A geofacet grid for South Korea administrative districts (\emph{Si-Gun-Gu}) based on
the Statistical Geographic Information Service (SGIS) standard in 2020.
Non-autonomous districts in cities are retained as separate entities.
This grid can be used with the \href{https://CRAN.R-project.org/package=geofacet}{geofacet}
package to create faceted visualizations based on geographic layout.
}
\details{
\itemize{
\item name Name of the district/municipal-level (Sigungu) administrative unit
\item code SGIS code of the district/municipal-level (Sigungu) administrative unit
\item row Row position in the geofacet grid
\item col Column position in the geofacet grid
}
}
\keyword{datasets}
